Mixed-Up Code Exercises
------------------------

Answer the following **Mixed-Up Code** or **Activecode** questions to
assess what you have learned in this chapter.

.. selectquestion:: cond_recc_p1_sq
  :fromid: cond_recc_p1, cond_recc_p1_ac_q
  :toggle:

.. selectquestion:: cond_recc_p2_sq
  :fromid: cond_recc_p2, cond_recc_p2_ac_q
  :toggle:

.. selectquestion:: cond_recc_p3_sq
  :fromid: cond_recc_p3, cond_recc_p3_ac_q
  :toggle:

.. selectquestion:: cond_recc_p4_sq
  :fromid: cond_recc_p4, cond_recc_p4_ac_q
  :toggle:

.. selectquestion:: cond_recc_p5_sq
  :fromid: cond_recc_p5, cond_recc_p5_ac_q
  :toggle:

.. selectquestion:: cond_recc_p6_sq
  :fromid: cond_recc_p6, cond_recc_p6_ac_q
  :toggle:

.. selectquestion:: cond_recc_p7_sq
  :fromid: cond_recc_p7, cond_recc_p7_ac_q
  :toggle:

.. selectquestion:: cond_recc_p8_sq
  :fromid: cond_recc_p8, cond_recc_p8_ac_q
  :toggle:

.. selectquestion:: cond_recc_p9_sq
  :fromid: cond_recc_p9, cond_recc_p9_ac_q
  :toggle:

.. selectquestion:: cond_recc_p10_sq
  :fromid: cond_recc_p10, cond_recc_p10_ac_q
  :toggle:
